==> dynamodb-keyspace-0.0.6.tgz: package/dist-es/command/Put.js <==
import { PutCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { assertReturnValuesAttributes } from '../util/returnValuesAttributes';
import { lowerCaseKeys, upperCaseKeys } from '../util/keyCapitalize';
import { executeMiddleware, executeMiddlewares } from '../Middleware';
import { applyDefaults } from '../util/defaults';
const PUT_COMMAND_INPUT_DATA_TYPE = 'PutCommandInput';
const PUT_COMMAND_INPUT_HOOK = ['CommandInput', 'WriteCommandInput', PUT_COMMAND_INPUT_DATA_TYPE];
const PUT_COMMAND_OUTPUT_DATA_TYPE = 'PutCommandOutput';
const PUT_COMMAND_OUTPUT_HOOK = ['CommandOutput', 'WriteCommandOutput', PUT_COMMAND_OUTPUT_DATA_TYPE];
export class DkPutCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: PUT_COMMAND_INPUT_DATA_TYPE, hooks: PUT_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: PUT_COMMAND_OUTPUT_DATA_TYPE, hooks: PUT_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, [
                'returnConsumedCapacity',
                'returnItemCollectionMetrics',
                'returnValuesOnConditionCheckFailure'
            ]);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            const upperCaseInput = upperCaseKeys(postMiddlewareInput);
            return upperCaseInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const lowerCaseOutput = lowerCaseKeys(output);
            const attributes = output.Attributes;
            assertReturnValuesAttributes(attributes, this.input.returnValues);
            const formattedOutput = {
                ...lowerCaseOutput,
                attributes
            };
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: formattedOutput
            }, middleware);
            if (postMiddlewareOutput.consumedCapacity)
                await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: postMiddlewareOutput.consumedCapacity }, middleware);
            if (postMiddlewareOutput.itemCollectionMetrics)
                await executeMiddleware('ItemCollectionMetrics', { dataType: 'ItemCollectionMetrics', data: postMiddlewareOutput.itemCollectionMetrics }, middleware);
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new PutCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}

==> dynamodb-keyspace-0.0.7.tgz: package/dist-es/command/Put.js <==
import { PutCommand } from '@aws-sdk/lib-dynamodb';
import { DkCommand } from './Command';
import { assertReturnValuesAttributes } from '../util/returnValuesAttributes';
import { uncapitalizeKeys, capitalizeKeys } from 'object-key-casing';
import { executeMiddleware, executeMiddlewares } from '../Middleware';
import { applyDefaults } from '../util/defaults';
const PUT_COMMAND_INPUT_DATA_TYPE = 'PutCommandInput';
const PUT_COMMAND_INPUT_HOOK = ['CommandInput', 'WriteCommandInput', PUT_COMMAND_INPUT_DATA_TYPE];
const PUT_COMMAND_OUTPUT_DATA_TYPE = 'PutCommandOutput';
const PUT_COMMAND_OUTPUT_HOOK = ['CommandOutput', 'WriteCommandOutput', PUT_COMMAND_OUTPUT_DATA_TYPE];
export class DkPutCommand extends DkCommand {
    constructor(input) {
        super(input);
        this.inputMiddlewareConfig = { dataType: PUT_COMMAND_INPUT_DATA_TYPE, hooks: PUT_COMMAND_INPUT_HOOK };
        this.outputMiddlewareConfig = { dataType: PUT_COMMAND_OUTPUT_DATA_TYPE, hooks: PUT_COMMAND_OUTPUT_HOOK };
        this.handleInput = async ({ defaults, middleware }) => {
            const postDefaultsInput = applyDefaults(this.input, defaults, [
                'returnConsumedCapacity',
                'returnItemCollectionMetrics',
                'returnValuesOnConditionCheckFailure'
            ]);
            const { data: postMiddlewareInput } = await executeMiddlewares([...this.inputMiddlewareConfig.hooks], {
                dataType: this.inputMiddlewareConfig.dataType,
                data: postDefaultsInput
            }, middleware);
            const upperCaseInput = capitalizeKeys(postMiddlewareInput);
            return upperCaseInput;
        };
        this.handleOutput = async (output, { middleware }) => {
            const lowerCaseOutput = uncapitalizeKeys(output);
            const attributes = output.Attributes;
            assertReturnValuesAttributes(attributes, this.input.returnValues);
            const formattedOutput = {
                ...lowerCaseOutput,
                attributes
            };
            const { data: postMiddlewareOutput } = await executeMiddlewares([...this.outputMiddlewareConfig.hooks], {
                dataType: this.outputMiddlewareConfig.dataType,
                data: formattedOutput
            }, middleware);
            if (postMiddlewareOutput.consumedCapacity)
                await executeMiddleware('ConsumedCapacity', { dataType: 'ConsumedCapacity', data: postMiddlewareOutput.consumedCapacity }, middleware);
            if (postMiddlewareOutput.itemCollectionMetrics)
                await executeMiddleware('ItemCollectionMetrics', { dataType: 'ItemCollectionMetrics', data: postMiddlewareOutput.itemCollectionMetrics }, middleware);
            return postMiddlewareOutput;
        };
        this.send = async (clientConfig) => {
            const input = await this.handleInput(clientConfig);
            const output = await clientConfig.client.send(new PutCommand(input));
            return this.handleOutput(output, clientConfig);
        };
    }
}
